@@ -30,7 +30,7 @@
 
 import time
 import os
-import math
+import pickle
 import shutil
 import tempfile
 
@@ -43,9 +43,6 @@ from supybot.i18n import PluginInternationalization, internationalizeDocstring
 _ = PluginInternationalization('Scheduler')
 import supybot.world as world
 
-import supybot.utils.minisix as minisix
-pickle = minisix.pickle
-
 datadir = conf.supybot.directories.data()
 filename = conf.supybot.directories.data.dirize('Scheduler.pickle')
 
