@@ -49,7 +49,6 @@ except ImportError:
 import supybot.conf as conf
 import supybot.utils as utils
 from supybot.commands import *
-import supybot.utils.minisix as minisix
 import supybot.plugins as plugins
 import supybot.ircutils as ircutils
 import supybot.registry as registry
@@ -237,12 +236,8 @@ class Unix(callbacks.Plugin):
                           'not available.'), Raise=True)
             (out, err) = inst.communicate()
             inst.wait()
-            if minisix.PY3:
-                lines = [i.decode('utf-8').rstrip() for i in out.splitlines()]
-                lines = list(map(str, lines))
-            else:
-                lines = out.splitlines()
-                lines = list(map(str.rstrip, lines))
+            lines = [i.decode('utf-8').rstrip() for i in out.splitlines()]
+            lines = list(map(str, lines))
             lines = filter(None, lines)
             irc.replies(lines, joiner=' ')
         else:
