@@ -448,7 +448,8 @@ class User(callbacks.Plugin):
             irc.errorNotRegistered()
         else:
             if u == user or u._checkCapability('admin'):
-                irc.reply('[%s]' % '; '.join(user.capabilities), private=True)
+                irc.reply('[%s]' % '; '.join(sorted(user.capabilities)),
+                          private=True)
             else:
                 irc.error(conf.supybot.replies.incorrectAuthentication(),
                           Raise=True)
