@@ -46,6 +46,7 @@ except ImportError: # Windows!
 
 from . import callbacks, conf, ircdb, ircmsgs, ircutils, log, \
         utils, world
+from .dynamicScope import dynamic
 from .utils import minisix
 from .i18n import PluginInternationalization, internationalizeDocstring
 _ = PluginInternationalization()
@@ -88,6 +89,20 @@ def _rlimit_min(a, b):
     else:
         return min(soft, heap_size)
 
+def _process_target(f, q, heap_size, *args, **kwargs):
+    """Called by :func:`process`"""
+    if resource:
+        rsrc = resource.RLIMIT_DATA
+        (soft, hard) = resource.getrlimit(rsrc)
+        soft = _rlimit_min(soft, heap_size)
+        hard = _rlimit_min(hard, heap_size)
+        resource.setrlimit(rsrc, (soft, hard))
+    try:
+        r = f(*args, **kwargs)
+        q.put([False, r])
+    except Exception as e:
+        q.put([True, e])
+
 def process(f, *args, **kwargs):
     """Runs a function <f> in a subprocess.
     
@@ -122,21 +137,9 @@ def process(f, *args, **kwargs):
                 '(See https://github.com/travis-ci/travis-core/issues/187\n'
                 'for more information about this bug.)\n')
         raise
-    def newf(f, q, *args, **kwargs):
-        if resource:
-            rsrc = resource.RLIMIT_DATA
-            (soft, hard) = resource.getrlimit(rsrc)
-            soft = _rlimit_min(soft, heap_size)
-            hard = _rlimit_min(hard, heap_size)
-            resource.setrlimit(rsrc, (soft, hard))
-        try:
-            r = f(*args, **kwargs)
-            q.put([False, r])
-        except Exception as e:
-            q.put([True, e])
-    targetArgs = (f, q,) + args
-    p = callbacks.CommandProcess(target=newf,
-                                args=targetArgs, kwargs=kwargs)
+    targetArgs = (f, q, heap_size) + args
+    p = callbacks.CommandProcess(target=_process_target,
+                                 args=targetArgs, kwargs=kwargs)
     try:
         p.start()
     except OSError as e:
@@ -1070,7 +1073,17 @@ class getopts(context):
     def __call__(self, irc, msg, args, state):
         if LOG_CONVERTERS:
             log.debug('args before %r: %r', self, args)
-        (optlist, rest) = getopt.getopt(args, self.getoptLs, self.getoptL)
+
+        # look for the first '--' token, it forcefully ends the getopt list,
+        # which allows the next arguments to start with a -
+        try:
+            sep = args.index('--')
+        except ValueError:
+            sep = None
+        else:
+            log.debug('getopt stopping at "--" token at position %d', sep)
+
+        (optlist, rest) = getopt.getopt(args[:sep], self.getoptLs, self.getoptL)
         getopts = []
         for (opt, arg) in optlist:
             if opt.startswith('--'):
@@ -1088,7 +1101,11 @@ class getopts(context):
             else:
                 getopts.append((opt, True))
         state.args.append(getopts)
-        args[:] = rest
+
+        if sep is None:
+            args[:] = rest
+        else:
+            args[:sep+1] = rest
         if LOG_CONVERTERS:
             log.debug('args after %r: %r', self, args)
 
