@@ -140,13 +140,13 @@ class ValuesTestCase(SupyTestCase):
         self.assertIsNot(v(), data)
 
         with v.editable() as dict_:
-            dict_['supy'] = 'bot'
+            dict_['supy'] = ['bot']
             del dict_['qux']
             self.assertNotIn('supy', v())
             self.assertIn('qux', v())
         self.assertIn('supy', v())
-        self.assertEqual(v()['supy'], 'bot')
-        self.assertIsNot(v()['supy'], 'bot')
+        self.assertEqual(v()['supy'], ['bot'])
+        self.assertIsNot(v()['supy'], ['bot'])
         self.assertNotIn('qux', v())
 
     def testNormalizedString(self):
